@@ -1,11 +1,15 @@
 /*
  * String Utility Library
  *
- * $RCSfile: libdgstr.h,v $
- * $Revision: 1.1.1.1 $
- * $Date: 2009/02/17 09:36:25 $
+ * $RCSfile$
+ * $Revision$
+ * $Date$
  */
 
+#ifdef HAVE_CONFIGH
+#include "../../config.h"
+#endif
+
 #ifndef _LIBDGSTR_H_
 #define _LIBDGSTR_H_
 
