@@ -19,9 +19,9 @@
  */
 
 /*
- * $RCSfile: mailzip_tmpl.c,v $
- * $Revision: 1.9 $
- * $Date: 2012/09/11 06:55:13 $
+ * $RCSfile$
+ * $Revision$
+ * $Date$
  */
 
 #include <stdio.h>
@@ -514,6 +514,7 @@ encode_mime_from_jis(char *jis_str)
         if (cnt == 0) {
             break;
         }
+
         // allocate memory for temporary buffer
         tmp_str = (char *)calloc(strlen(buf) + 1, sizeof(char));
         if (tmp_str == NULL) {
@@ -979,6 +980,9 @@ tmpl_tag_replace(char *tmp, struct mailzip mz, struct rcptinfo *other, char *sen
     int name_len = 0, ret_len = 0, total_len = 0;
     int tagnum = 0;
 
+    /* Repairing for encoded Subject by MIME encode(2014/05/14(wed)) */
+    char *tmp_dec = NULL;
+
     struct strtag tmpl_tag[] = {
         {"SUBJECT", 7, NULL},
         {"DATE", 4, NULL},
@@ -1107,15 +1111,30 @@ tmpl_tag_replace(char *tmp, struct mailzip mz, struct rcptinfo *other, char *sen
     tmpl_tag[FILENAME].st_str = filename;
     free(tmpf);
 
-    if (dg_str2code(tmp, &tmpl, STR_UTF8, STR_JIS) != 0) {
+    /* Repairing for encoded Subject by MIME encode(2014/05/14(wed)) */
+    /* If Subject is encoded by MIME encode, change to not encoded strings.
+     * Non-encoded strings are not processed.
+     */
+    tmp_dec = decode_mime(tmp);
+    if (tmp_dec == NULL) {
+        log(ERR_MEMORY_ALLOCATE, "tmpl_tag_replace of decode_mime", 
+            "tmp_dec", strerror(errno));
+	return(ERROR);
+    }
+
+    /* Repairing for encoded Subject by MIME encode(2014/05/14(wed)) */
+    if (dg_str2code(tmp_dec, &tmpl, STR_UTF8, STR_JIS) != 0) {
         log(ERR_CHARCODE_CONVERT, "tmpl_tag_replace");
 	free(tmpp);
+        free(tmp_dec);
 	if (subject != NULL) {
 	    free(subject);
 	}
 	free(filename);
 	return(ERROR);
     }
+    /* Repairing for encoded Subject by MIME encode(2014/05/14(wed)) */
+    free(tmp_dec);
 
     //replace tag
     tmptagp = str_replace_tag(tmpl, STARTTAG, ENDTAG, tmpl_tag, tagnum);
