@@ -20,8 +20,8 @@
 
 /*
  * $RCSfile: zipconv.c,v $
- * $Revision: 1.23 $
- * $Date: 2013/01/09 08:18:13 $
+ * $Revision: 1.25 $
+ * $Date: 2014/05/09 04:43:07 $
  */
 
 #include <stdio.h>
@@ -105,7 +105,9 @@ mailzip_clean(struct mailzip mz)
     }
 
     if (mz.date != NULL) {
-	free(mz.date);
+//        free(mz.date);
+        /* Repairing The display of the date 2014/05/08 (Thu) */
+        g_free(mz.date);
     }
 
     if (mz.encfilepath != NULL) {
@@ -382,7 +384,10 @@ add_attach_file(struct mailzip *mz, struct rcptinfo *rcpt)
     g_object_unref (part);
     g_object_unref (wrapper);
     g_object_unref (f_stream);
+
+#ifndef GMIME_2_4
     g_object_unref (object);
+#endif
 
     pthread_mutex_unlock(&gmime_lock);
     return 0;
@@ -661,8 +666,15 @@ parse_mail(struct mailinfo *minfo, struct config *cfg, struct mailzip *mz)
 
     /* Get header subject */
     mz->subject = g_mime_message_get_subject(mz->message);
+
     /* Get header date */
-    mz->date = g_mime_message_get_date_string(mz->message);
+    if (cfg->cf_settimezone == 0) {
+        mz->date = g_mime_message_get_date_string(mz->message);
+    } else {
+        /* Repairing The display of the date 2014/05/08 (Thu) */
+        mz->date =  g_mime_utils_header_format_date (mz->message->date,
+                                                     cfg->cf_settimezone);
+    }
 
     /* gmime part object */
     object = g_mime_message_get_mime_part(mz->message);
@@ -716,6 +728,8 @@ parse_mail(struct mailinfo *minfo, struct config *cfg, struct mailzip *mz)
         g_object_unref (object);
 	pthread_mutex_unlock(&gmime_lock);
         if (ret == -2) {
+/* if cannot convert character code then set filename is unknown file */
+printf("errror \n");
             /* could not detect/convert attached filename's encoding
              * returning specific value */
             return(PM_INVALID_FILENAME);
@@ -723,7 +737,9 @@ parse_mail(struct mailinfo *minfo, struct config *cfg, struct mailzip *mz)
 	return -1;
     }
 
+#ifndef GMIME_2_4
     g_object_unref (object);
+#endif
 
     /* Not attach file */
     if (mz->namelist == NULL) {
@@ -792,12 +808,24 @@ drop_file(GMimeObject *object, struct config *cfg, struct mailzip *mz)
 	
 	/* convert str code */
 	if (dg_str2code(tmpname, &tmpfilename, STR_UTF8, cfg->cf_strcode) != 0) {
+            /* START ADD 20150323 */
+            /* if convert str code error then  make unknown file*/
+            tmpfilename = strdup(cfg->cf_attachmentfilealias);
+            if (tmpfilename == NULL) {
+	        log(ERR_MEMORY_ALLOCATE, "drop_file", "tmpfilename", strerror(errno));
+	        g_object_unref (att);
+	        return -1;
+            }
+
 	    log(ERR_CHARCODE_CONVERT, "drop_file");
-            g_object_unref (att);
-	    free(tmpname);
+            /* delete old code */
+            //g_object_unref (att);
+	    //free(tmpname);
             /* could not detect/convert encoding
              * returning specific value */
-	    return -2;
+	    //return -2;
+
+            /* END ADD 20150323 */
 	}
 	free(tmpname);
 
